===========
Koodous SDK
===========


.. image:: https://img.shields.io/pypi/v/koodous.svg
        :target: https://pypi.python.org/pypi/koodous

.. image:: https://readthedocs.org/projects/koodous/badge/?version=latest
        :target: https://koodous-sdk.readthedocs.io/en/latest/
        :alt: Documentation Status




This is the Python SDK developed by our team to use Koodous easily.

Koodous works with many different hashing functions, but we prefer sha256 to manage all samples in the better way.


* Free software: Apache Software License 2.0
* Sdk documentation: SdkDocumentation_
* Koodous documentation: KoodousDocumentation_


Features
--------

* Interact with the Koodous API easily.
* Download individual samples (requires api key).
* Download the samples, analyses and detected feed (requires api key with privileges).

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _SdkDocumentation: https://koodous-sdk.readthedocs.io/en/latest/
.. _KoodousDocumentation: https://docs.koodous.com/
